/*
 * Copyright 2010-2012 Roman Yepishev <roman.yepishev@ubuntu.com>
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 3, as published
 * by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranties of
 * MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// LP: 983361

using GLib;

class UpdateMonitor : GLib.Object {
    private FileMonitor monitor = null;
    private string monitored_path = null;
    private bool is_restart_scheduled = false;

    public UpdateMonitor(string path) {
        monitored_path = path;

        var file = File.new_for_path(monitored_path);
        monitor = file.monitor_file(FileMonitorFlags.NONE);
        monitor.changed.connect(file_changed_cb);
    }

    private void file_changed_cb(File file, File? of, FileMonitorEvent event_type) {
        if (event_type != FileMonitorEvent.CHANGES_DONE_HINT) {
            return;
        }

        if (file.get_path() == monitored_path) {
            if (! is_restart_scheduled) {
                is_restart_scheduled = true;
                message("%s has changed, scheduling a restart\n", monitored_path);
                Timeout.add_seconds(5, restart_application);
            }
        }
    }

    private bool restart_application() {
        // --pkg posix, path,        argv[0]
        Posix.execlp(monitored_path, monitored_path);
        // unreachable
        return false;
    }
}
